# practipy
Python conviencience functions, classes and decorators to make my life easier.
Currently contains a small subset of [fastcore](https://github.com/fastai/fastcore) code, but will be extended with my own code over time.
